@@ -5,9 +5,9 @@ use arkworks_utils::utils::common::Curve as ArkCurve;
 use rand::rngs::OsRng;
 
 use crate::proof::{MixerProofInput, Proof};
-use crate::types::{Backend, Curve, OpStatusCode};
+use crate::types::{Backend, Curve, OpStatusCode, OperationError};
 
-pub fn create_proof(mixer_proof_input: MixerProofInput, rng: &mut OsRng) -> Result<Proof, OpStatusCode> {
+pub fn create_proof(mixer_proof_input: MixerProofInput, rng: &mut OsRng) -> Result<Proof, OperationError> {
 	let MixerProofInput {
 		recipient,
 		relayer,
@@ -52,9 +52,13 @@ pub fn create_proof(mixer_proof_input: MixerProofInput, rng: &mut OsRng) -> Resu
 			pk,
 			rng,
 		),
-		_ => return Err(OpStatusCode::InvalidProofParameters),
+		_ => return Err(OpStatusCode::InvalidProofParameters.into()),
 	}
-	.map_err(|_| OpStatusCode::InvalidProofParameters)?;
+	.map_err(|e| {
+		let mut error: OperationError = OpStatusCode::InvalidProofParameters.into();
+		error.data = Some(e.to_string());
+		error
+	})?;
 	Ok(Proof {
 		proof,
 		nullifier_hash,
